import logging

from env import ENDPOINT, ACCESS_ID, ACCESS_KEY, USERNAME, PASSWORD, DEVICE_ID
from tuya_iot import TuyaOpenAPI, TUYA_LOGGER


class SwitchClient:
    __schema = 'smartlife'
    __country_code = "86"
    __request_url = '/v1.0/devices/{}/commands'.format(DEVICE_ID)

    def __init__(self):
        TUYA_LOGGER.setLevel(logging.DEBUG)
        self.openapi = TuyaOpenAPI(ENDPOINT, ACCESS_ID, ACCESS_KEY)

    def authorize_if_no_token(self):
        if not self.openapi.is_connect():
            self.openapi.connect(USERNAME, PASSWORD, self.__country_code, self.__schema)

    def switch_on(self):
        self.authorize_if_no_token()
        commands = {'commands': [{'code': 'switch_1', 'value': True}]}
        self.openapi.post('/v1.0/devices/{}/commands'.format(DEVICE_ID), commands)

    def switch_off(self):
        self.authorize_if_no_token()
        commands = {'commands': [{'code': 'switch_1', 'value': False}]}
        self.openapi.post(self.__request_url, commands)
